%% LaTeX class for theses
%% Based on wissdoc.cls by Roland Bless, 1996-2001 (bless@telematik.informatik.uni-karlsruhe.de)
%% With adaptations by Timo Rohrberg, 2009 (timo.rohrberg@student.kit.edu)
%% And additions by Thorsten Haberecht, IPD - Chair Prof. Boehm, 2010 (thorsten.haberecht@kit.edu)
%% 
%% By Elia Henrichs, University of Hohenheim, Dep. Food Informatics - Jun.-Prof. Dr. Krupitzer, 2021-2023


%% --------------------------------
%% |              Basics            |
%% --------------------------------

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{thesis}
\LoadClass[a4paper,11pt,titlepage]{scrbook} % based on scrbook

%% --- End of Basics ---


%% --------------------------------
%% |            Packages          |
%% --------------------------------

\RequirePackage[utf8]{inputenc} % Input in ISO 8859-1 (Latin1)
\RequirePackage[T1]{fontenc}
\RequirePackage{ae}                 % Almost european, virtual T1-Font
\RequirePackage[pdftex]{graphicx}
\RequirePackage{vmargin}          % Adjust margins in a simple way
\RequirePackage{fancyhdr}         % Define simple headings
\RequirePackage{subfigure}
\RequirePackage{url}
\RequirePackage[absolute,overlay]{textpos}
\RequirePackage{tikz}
\RequirePackage{listings}
\RequirePackage{acronym}	 % For automated acronym usage
\RequirePackage{algorithm}	  % Code-Listings
\RequirePackage{algorithmic}	  % Code-Listings
% see http://www.ctan.org/tex-archive/macros/latex/contrib/algorithm2e/algorithm2e.pdf for more sophisticated algorithm listings
\RequirePackage{tabularx}
\RequirePackage{arydshln}	 % dashed lines in array/tabulars

\RequirePackage{geometry}
\RequirePackage{xcolor}
\RequirePackage{etoolbox}
\RequirePackage{pgfgantt} % Must be behind graphicx or will produce errors otherwise
\RequirePackage{rotating} % Same here (see above)

\RequirePackage[raiselinks=true,
		      bookmarks=true,
		      bookmarksopenlevel=1,
		      bookmarksopen=true,
		      bookmarksnumbered=true,
		      hyperindex=true,
		      plainpages=false,
		      pdfpagelabels=true,
		      pdfborder={0 0 0.5},
		      colorlinks=false,						
		      linkbordercolor={0 0.61 0.50},   
		      citebordercolor={0 0.61 0.50}]{hyperref}  %{0.57 0.74 0.57}

%% --- End of Packages ---


%% -------------------------------
%% |      Globale Settings     |
%% -------------------------------

\setcounter{secnumdepth}{3} % Numbering also for \subsubsections
\setcounter{tocdepth}{3}    % Register \subsubsections in content directory

\setpapersize{A4}
\setmarginsrb{3cm}{1cm}{3cm}{1cm}{6mm}{7mm}{5mm}{15mm}

\parindent 0cm                     % Do not indent beginning of paragraph
\parskip1.5ex plus0.5ex minus0.5ex % Margin between paragraphs

%% --- End of Globale Settings ---


%% -------------------------------
%% |          Languages         |
%% -------------------------------

\newif\ifCLASSOPTIONenglish	\CLASSOPTIONenglishtrue
\newif\ifCLASSOPTIONdeutsch	\CLASSOPTIONdeutschfalse

% English section
\DeclareOption{english}{%
 \CLASSOPTIONenglishtrue\CLASSOPTIONdeutschfalse
 \def\andname{and}%
 \def\lastandname{ and}%
 \def\appendixname{Appendix}%
 \def\chaptername{Chapter}%
 \def\contentsname{Table of Content}%
 \def\examplename{Example}%
 \def\figurename{Fig.}%
 \def\listfigurename{List of Figures}%
 \def\listtablename{List of Tables}%
 \def\lstlistingname{Listing}%
 \def\lstlistlistingname{List of Listings}%
 \def\partname{Part}%
 \def\subclassname{{\it Subject Classifications\/}:}%
 \def\submissionname{Submission}%
 \def\tablename{Table}%
%\def\theoremname{Theorem}%
 \def\studycourse{Course of Study}%
 \def\matricel{Matriculation Number}%
 \def\authorDepartment{Institute of Food Science and Biotechnology}%
 \def\authorChair{Department of Food Informatics}%
 \def\authorAssociation{University of Hohenheim}%
 \def\associationLogo{logos/logo_en.pdf}%
}

% German section
\DeclareOption{deutsch}{%
 \CLASSOPTIONdeutschtrue\CLASSOPTIONenglishfalse
 \def\andname{und}%
 \def\lastandname{ und}%
 \def\appendixname{Anhang}%
 \def\chaptername{Kapitel}%
 \def\contentsname{Inhaltsverzeichnis}%
 \def\examplename{Beispiel}%
 \def\figurename{Abb.}%
 \def\listfigurename{Abbildungsverzeichnis}%
 \def\listtablename{Tabellenverzeichnis}%
 \def\lstlistingname{Quellcode}%
 \def\lstlistlistingname{Quellcodeverzeichnis}%
 \def\partname{Teil}%
 \def\subclassname{{\it Subject Classifications\/}:}%
 \def\submissionname{Abgabe}%
 \def\tablename{Tabelle}%
%\def\theoremname{Theorem}%
 \def\studycourse{Studiengang}%
 \def\matricel{Matrikelnummer}%
 \def\authorDepartment{Institut f\"ur Lebensmittelwissenschaften und Biotechnologie}%
 \def\authorChair{Fachgebiet f\"ur Lebensmittelinformatik}%
 \def\authorAssociation{Universit\"at Hohenheim}%
 \def\associationLogo{logos/logo_de.pdf}%
}

\newif\ifdeutschoption
\DeclareVoidOption{deutsch}{
 \deutschoptiontrue
}

\ExecuteOptions{english}
%\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrbook}}
\ProcessOptions\relax

\ProcessKeyvalOptions*
\ifdeutschoption
\RequirePackage[ngerman]{babel}
\usepackage[fixlanguage]{babelbib}	% sets german style for literature entries
\selectbiblanguage{ngerman}			% for \bibliographystyle{babalpha}
\newcommand{\AIstep}{Arbeitsschritt}
\newcommand{\AIsystem}{Eingesetzte(s) KI-System(e)}
\newcommand{\AIdescription}{Beschreibung der Verwendungsweise}
\else
\RequirePackage[english]{babel}
\newcommand{\AIstep}{Working step}
\newcommand{\AIsystem}{Used AI system(s)}
\newcommand{\AIdescription}{Description of the use}
\fi

%% --- End of Languages ---


%% -------------------------------
%% |             Colors            |
%% -------------------------------

\definecolor{background}{RGB}{31,83,148}
\definecolor{titlecolor}{RGB}{255,255,255}

%% --- End of Colors ---


%% -------------------------------
%% |     Header & Footer     |
%% -------------------------------

\pagestyle{fancy}
\renewcommand{\chaptermark}[1]{\markboth{\thechapter. #1}{}}
\renewcommand{\sectionmark}[1]{\markright{\thesection\ #1}{}}
\fancyhf{}
%\fancyhead[LE,RO]{{\headfont\thepage}}			% Left/right header for even/odd pages
\fancyhead[RO]{\headfont\nouppercase{\rightmark}}	% Header for left page (odd)
\fancyhead[LE]{\headfont\nouppercase{\leftmark}}		% Header for right page (even)
\fancyfoot[C]{\thepage}
\renewcommand{\headrulewidth}{0.5pt}
\renewcommand{\footrulewidth}{0pt}
\fancypagestyle{plain}{%
\fancyhf{}								% No Header and Footer fields
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
\fancyfoot[C]{\thepage}
}

%% --- End of Header & Footer ---


%% -------------------------------
%% |      Style of Captions    |
%% -------------------------------

\renewcommand{\chaptername}{}
\newlength{\chapnolen}
\newlength{\chapparlen}
\newsavebox{\chapno}
\renewcommand{\@makechapterhead}[1]{
  \vspace*{0.2\textheight}
  \vskip 15\p@
  {\parindent \z@ \raggedright \normalfont
    \ifnum \c@secnumdepth >\m@ne
      \if@mainmatter
        \savebox{\chapno}{\chapterheadfont\huge\bfseries \thechapter.}
        \settowidth{\chapnolen}{\usebox{\chapno}}
        \parbox[t]{\chapnolen}{\usebox{\chapno}}\nobreak\leavevmode
      \fi
    \fi
    \interlinepenalty\@MM
    \setlength{\chapparlen}{\textwidth}
    \addtolength{\chapparlen}{-1.0\chapnolen}
    \addtolength{\chapparlen}{-2ex}
    \leavevmode\nobreak
    \parbox[t]{\chapparlen}{\raggedright\chapterheadfont\huge \bfseries #1\par\nobreak}
    \vskip 40\p@
  }}

\renewcommand{\@makeschapterhead}[1]{
  \vspace*{50\p@}
  {\parindent \z@ \raggedright
    \normalfont
    \interlinepenalty\@M
    \chapterheadfont \huge \bfseries  #1\par\nobreak
    \vskip 40\p@
  }
}

\renewcommand{\section}{%
\@startsection{section}%
{1}		% Structure level
{0mm}	% Indention
{2ex plus 1ex minus 1ex}			% Pre-Margin
{0.5ex plus 0.5ex minus 0.5ex}		% Post-Margin
{\chapterheadfont\Large\bfseries}	% Style
}
\renewcommand{\subsection}{%
\@startsection{subsection}%
{2}		% Structure level
{0mm}	% Indention
{1.5ex plus 1ex minus 0.5ex}		% Pre-Margin
{0.3ex plus 0.3ex minus 0.3ex}		% Post-Margin
{\chapterheadfont\large\bfseries}	% Style
}
\renewcommand{\subsubsection}{%
\@startsection{subsubsection}%
{3}		% Structure level
{0mm}	% Indention
{1.5ex plus 1ex minus 0.5ex}			% Pre-Margin
{0.2ex plus 0.2ex minus 0.2ex}			% Post-Margin
{\chapterheadfont\normalsize\bfseries}	% Style
}
\renewcommand{\paragraph}{%
\@startsection{paragraph}%
{4}		% Structure level
{0mm}	% Indention
{1.3ex plus 1ex minus 0.3ex}			% Pre-Margin
{0.2ex plus 0.2ex minus 0.2ex}			% Post-Margin
{\chapterheadfont\normalsize\bfseries}	% Style
}
\renewcommand{\subparagraph}{%
\@startsection{subparagraph}%
{5}		% Structure level
{0mm}	% Indention
{1ex plus 1ex minus 0.2ex}				% Pre-Margin
{0.1ex plus 0.1ex minus 0.1ex}			% Post-Margin
{\chapterheadfont\normalsize\bfseries}	% Style
}



%% --- End of Captions style ---


%% -------------------------------
%% |        Style of TOC        |
%% -------------------------------

\let\oldtableofcontents\tableofcontents
\renewcommand{\tableofcontents}{{\pdfbookmark{\contentsname}{\contentsname}\chapterheadfont\oldtableofcontents}}
\let\@olddottedtocline\@dottedtocline
\renewcommand{\@dottedtocline}[5]{\@olddottedtocline{#1}{#2}{#3}{#4}{\chapterheadfont #5}}

%% --- End of TOC style ---


%% -------------------------------
%% |     Style of Appendix    |
%% -------------------------------

\renewcommand\appendix{\par 
   \setcounter{section}{0}% 
   \setcounter{subsection}{0}% 
   \setcounter{figure}{0}%
   \setcounter{lstlisting}{0}%
   \renewcommand\thesection{\Alph{section}}% 
   \renewcommand\thefigure{\Alph{section}.\arabic{figure}} 
   \renewcommand\thetable{\Alph{section}.\arabic{table}}
   \renewcommand\thelstlisting{\Alph{section}.\arabic{lstlisting}}}

%% --- End of Appendix style ---


%% ---------------------------------
%% |        Style of Listings      |
%% ---------------------------------

\lstset{
 frame=single,
 breaklines=true,
 numbers=left
}

%% --- End of Listings style ---


%% ---------------------------------
%% |        Further Settings      |
%% ---------------------------------

\newcommand{\changefont}[3]{\fontfamily{#1} \fontseries{#2} \fontshape{#3} \selectfont}
\newcommand{\chapterheadfont}{}
\newcommand{\blankpage}{ \clearpage{\pagestyle{empty}\cleardoublepage}}

\def\webadress{https://foodinformatics.uni-hohenheim.de/}
\DeclareGraphicsExtensions{.svg}

%% --- End of Further Settings ---

%% ***** END OF CLASS *****